"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jwt = require("koa-jwt");
exports.DEFAULT_SECRET = 'default';
exports.DEFAULT_REGEXP = '/public/';
exports.DEFAULT_PREFIX = 'Bearer';
function createJwtMiddleware(jwtSecret = exports.DEFAULT_SECRET, appUnprotectedUrlsRegexp = exports.DEFAULT_REGEXP, jwtAuthHeaderPrefix = exports.DEFAULT_PREFIX) {
    return jwt({
        secret: jwtSecret,
        getToken: function (opts) {
            const ctx = this;
            if (!ctx.header || !ctx.header.authorization) {
                return;
            }
            const parts = ctx.header.authorization.split(' ');
            if (parts.length === 2) {
                const scheme = parts[0];
                const credentials = parts[1];
                if (scheme === jwtAuthHeaderPrefix) {
                    return credentials;
                }
            }
            if (!opts.passthrough) {
                ctx.throw(401, 'Bad Authorization header format. Format is "Authorization: Bearer <token>"');
            }
        }
    }).unless({
        path: [
            new RegExp(appUnprotectedUrlsRegexp)
        ],
        method: 'OPTIONS'
    });
}
exports.createJwtMiddleware = createJwtMiddleware;
