"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const validator_1 = require("./validator");
const validation_1 = require("../error/validation");
class ItemValidator {
    get item() {
        return this._item;
    }
    get optional() {
        if (!this._optionalInstance) {
            this._optionalInstance = new ItemValidator(this._item, true);
        }
        return this._optionalInstance;
    }
    ;
    constructor(item, isOptional = false) {
        this._item = Object.assign({}, item);
        this._isOptional = isOptional;
    }
    isInt(field, min = Number.MIN_SAFE_INTEGER, max = Number.MAX_SAFE_INTEGER) {
        return validator_1.Validator.isInt(this._item[field], min, max);
    }
    escape(field) {
        return validator_1.Validator.escape(this._item[field]);
    }
    isString(field, min = 1, max = 256) {
        return validator_1.Validator.isString(this._item[field], min, max);
    }
    isEmail(field) {
        return validator_1.Validator.isEmail(this._item[field]);
    }
    isArray(field, iterator) {
        return validator_1.Validator.isArray(this._item[field], iterator);
    }
}
exports.ItemValidator = ItemValidator;
function wrap(fn) {
    return function (field, ...args) {
        try {
            if (this._isOptional && !this._item.hasOwnProperty(field)) {
                return null;
            }
            return fn.apply(this, [field].concat(args));
        }
        catch (error) {
            const err = error instanceof validation_1.ValidationError ?
                error :
                new validation_1.ValidationError(validation_1.ValidationError.VALIDATION);
            err.details.invalidField = field;
            err.details.invalidValue = this._item[field];
            throw err;
        }
    };
}
Object.getOwnPropertyNames(ItemValidator.prototype).forEach((key) => {
    if (typeof Object.getOwnPropertyDescriptor(ItemValidator.prototype, key).get !== 'undefined') {
        return;
    }
    const value = ItemValidator.prototype[key];
    if (typeof value === 'function' && value.name !== 'constructor') {
        ItemValidator.prototype[key] = wrap(value);
    }
});
